import React from "react";
import { Button, Dropdown, Input } from "antd";
import type { MenuProps } from "antd";
export default function Menu() {
  const menuData: {
    key: string;
    label: string;
    type: "group";
    children: MenuProps["items"];
  }[] = [
    {
      key: "1",
      label: "文件",
      type: "group",
      children: [
        { key: "1-1", label: "新建" },
        { key: "1-2", label: "在新标签页打开" },
        { key: "1-3", label: "保存" },
        { key: "1-4", label: "保存为模版" },
        { key: "1-5", label: "发布模版" },
        { key: "1-6", label: "同步到数据表" },
        { key: "1-7", label: "导出为图片" },
      ],
    },
    {
      key: "2",
      label: "编辑",
      type: "group",
      children: [
        { key: "1-1", label: "撤销" },
        { key: "1-2", label: "恢复" },
        { key: "1-3", label: "清楚" },
        { key: "1-4", label: "剪切" },
        { key: "1-5", label: "复制" },
        { key: "1-6", label: "粘贴" },
        { key: "1-7", label: "删除" },
      ],
    },
    {
      key: "3",
      label: "视图",
      type: "group",
      children: [
        { key: "1-1", label: "菜单栏隐藏" },
        { key: "1-2", label: "侧边栏隐藏" },
        { key: "1-3", label: "演示模式" },
        { key: "1-4", label: "字段详情" },
        { key: "1-5", label: "重置视图" },
        { key: "1-6", label: "显示网格" },
        { key: "1-7", label: "显示关系" },
        { key: "1-8", label: "放大" },
        { key: "1-9", label: "缩小" },
        { key: "1-10", label: "全屏" },
      ],
    },
    {
      key: "4",
      label: "设置",
      type: "group",
      children: [
        { key: "1-1", label: "修改记录" },
        { key: "1-2", label: "自动保存" },
        { key: "1-3", label: "自动同步" },
      ],
    },
    {
      key: "5",
      label: "帮助",
      type: "group",
      children: [
        { key: "1-1", label: "快捷键" },
        { key: "1-2", label: "操作说明" },
      ],
    },
  ];

  return (
    <div className="flex-1 flex items-center">
      <div className="logo h-48px m-l-12px">
        <svg className="icon h-48px w-48px" aria-hidden="true">
          <use xlinkHref="#icon-shujujianmo"></use>
        </svg>
      </div>
      <div className="h-full">
        <div className="leading-32px flex items-center">
          <Input
            className="text-24px max-w-200px"
            variant="borderless"
            value={"模型名称"}
          />
          <div className="bg-#eee text-12px leading-20px color-#666 rounded-4px p-x-4px p-y-2px">上次保存时间：2024-12-13 13:21:23</div>
        </div>
        <div className="flex">
          {menuData.map((item) => {
            return (
              <Dropdown
                key={item.key}
                menu={{ items: item.children, style: { width: 200 } }}
                placement="bottomLeft"
              >
                <Button type="text" size="small">
                  {item.label}
                </Button>
              </Dropdown>
            );
          })}
        </div>
      </div>
    </div>
  );
}
